/* This file is part of the Nepomuk Project
   Copyright (c) 2008 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "bugmodel.h"
#include "bug.h"
#include "utils.h"

#include <nepomuk/resourcemanager.h>
#include <nepomuk/thing.h>

#include <KLocale>
#include <KDebug>


Q_DECLARE_METATYPE( Lino::Bug )

class Lino::BugModel::Private
{
public:
    QList<Bug> bugs;
};



Lino::BugModel::BugModel( QObject* parent )
    : QAbstractListModel( parent ),
      d( new Private() )
{
}


Lino::BugModel::~BugModel()
{
    delete d;
}


Lino::Bug Lino::BugModel::bugForIndex( const QModelIndex& index ) const
{
    if ( index.isValid() && index.row() < d->bugs.count() ) {
        return d->bugs[index.row()];
    }
    return Bug();
}


QModelIndex Lino::BugModel::indexForBug( const Bug& bug ) const
{
    return indexForBug( bug.resourceUri() );
}


QModelIndex Lino::BugModel::indexForBug( const QUrl& bugUri ) const
{
    // search the stupid way
    for ( int i = 0; i < d->bugs.count(); ++i ) {
        if ( d->bugs[i].resourceUri() == bugUri )
            return index( i, 0, QModelIndex() );
    }
    return QModelIndex();
}


QModelIndex Lino::BugModel::index( int row, int column, const QModelIndex& parent ) const
{
    return QAbstractListModel::index( row, column, parent );
}


QVariant Lino::BugModel::headerData( int section, Qt::Orientation, int role ) const
{
    if ( role == Qt::DisplayRole ) {
        switch( section ) {
        case 0:
            return i18n( "Bug description" );
        default:
            return i18n( "State" );
        }
    }
    return QVariant();
}


QVariant Lino::BugModel::data( const QModelIndex& index, int role ) const
{
    Bug bug = bugForIndex( index );
    switch( role ) {
    case Qt::DisplayRole:
        switch( index.column() ) {
        case 0:
            return bug.title().simplified();
        case 1:
            return Lino::bugStateString( bug.state() );
        }

    case BugRole:
        return QVariant::fromValue( bug );
    }
    return QVariant();
}


int Lino::BugModel::columnCount( const QModelIndex& parent ) const
{
    // FIXME: one for now, later maybe reporter and state and product and allow the gui to filter the columns
    return 2;
}


int Lino::BugModel::rowCount( const QModelIndex& parent ) const
{
    if ( parent.isValid() )
        return 0;
    else
        return d->bugs.count();
}


void Lino::BugModel::clear()
{
    d->bugs.clear();
    reset();
}


void Lino::BugModel::addBugs( const QList<Bug>& bugs )
{
    beginInsertRows( QModelIndex(), d->bugs.count(), d->bugs.count() + bugs.count() - 1 );
    d->bugs += bugs;
    endInsertRows();
}


void Lino::BugModel::setBugs( const QList<Bug>& bugs )
{
    d->bugs = bugs;
    reset();
}

#include "bugmodel.moc"
