/* This file is part of the Nepomuk Project
   Copyright (c) 2008 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef _LINO_BUG_MODEL_H_
#define _LINO_BUG_MODEL_H_

#include <QtCore/QAbstractListModel>

namespace Lino {

    class Bug;

    class BugModel : public QAbstractListModel
    {
        Q_OBJECT

    public:
        BugModel( QObject* parent = 0 );
        ~BugModel();

        enum CustomRoles {
            BugRole = 7777
        };

        QModelIndex index( int row, int column, const QModelIndex& parent ) const;
        QVariant headerData( int section, Qt::Orientation orientation, int role ) const;
        QVariant data( const QModelIndex& index, int role ) const;
        int rowCount( const QModelIndex& parent ) const;
        int columnCount( const QModelIndex& parent ) const;

        Bug bugForIndex( const QModelIndex& index ) const;
        QModelIndex indexForBug( const Bug& bug ) const;
        QModelIndex indexForBug( const QUrl& bugUri ) const;

    public Q_SLOTS:
        void clear();
        void setBugs( const QList<Lino::Bug>& bugs );
        void addBugs( const QList<Lino::Bug>& bugs );

    private:
        class Private;
        Private* const d;
    };
}

#endif
