/* This file is part of the Nepomuk Project
   Copyright (c) 2008 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef LINOBROWSERVIEW_H
#define LINOBROWSERVIEW_H

#include <QtGui/QWidget>
#include <QtCore/QTimer>

#include "ui_linobrowserview_base.h"

class QPainter;
class KUrl;
class QModelIndex;
class KJob;
namespace Lino {
    class Bug;
    class BugModel;
    class BugFilterModel;
    class RecommendedBugModel;
    class BugLoader;
}
class LinoBrowser;
class StringAnimator;


class LinoBrowserView : public QWidget, public Ui::linobrowserview_base
{
    Q_OBJECT
public:
    /**
     * Default constructor
     */
    LinoBrowserView( LinoBrowser* parent );

    /**
     * Destructor
     */
    virtual ~LinoBrowserView();

    Lino::Bug selectedBug() const;
    
Q_SIGNALS:
    void bugSelected( const QUrl& bugUrl );

public Q_SLOTS:
    void setBug( const Lino::Bug& bug );
    void setBug( const QUrl& url );
    void reload();
    void queryBugs( const QString& app, const QString& query );

private Q_SLOTS:
    void slotCurrentBugChanged( const QModelIndex& current, const QModelIndex& );
    void slotRelatedBugExecuted( const QModelIndex& index );
    void slotBugLoaderFinished( KJob* );
    void slotStateFilterChanged( int i );
    void slotBugModelChanged();
    void updateStatusBar();
    void slotTagsChanged();

private:
    LinoBrowser* m_mainWindow;
    Lino::BugModel* m_bugModel;
    Lino::BugFilterModel* m_sortModel;
    Lino::RecommendedBugModel* m_recommendedBugsModel;

    StringAnimator* m_stringAnimator;
    QTimer m_animationTimer;

    Lino::BugLoader* m_runningBugLoader;
};

#endif // LinoBrowserVIEW_H
