/* This file is part of the Nepomuk Project
   Copyright (c) 2008 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "urlhistory.h"

#include <QtCore/QStack>

#include <KAction>
#include <KStandardAction>


class UrlHistory::Private
{
public:
    UrlHistory* q;

    QUrl m_currentUrl;
    QStack<QUrl> m_backwardHistory;
    QStack<QUrl> m_forwardHistory;

    KAction* backwardAction;
    KAction* forwardAction;

    void updateActions();
};


void UrlHistory::Private::updateActions()
{
    backwardAction->setEnabled( !m_backwardHistory.isEmpty() );
    forwardAction->setEnabled( !m_forwardHistory.isEmpty() );
    emit q->backwardAvailable( !m_backwardHistory.isEmpty() );
    emit q->forwardAvailable( !m_forwardHistory.isEmpty() );
}


UrlHistory::UrlHistory( QObject* parent )
    : QObject( parent ),
      d( new Private() )
{
    d->q = this;
    d->backwardAction = KStandardAction::back( this, SLOT( backward() ), this );
    d->forwardAction = KStandardAction::forward( this, SLOT( forward() ), this );
    d->backwardAction->setEnabled( false );
    d->forwardAction->setEnabled( false );
}


UrlHistory::~UrlHistory()
{
    delete d;
}


KAction* UrlHistory::backwardAction()
{
    return d->backwardAction;
}


KAction* UrlHistory::forwardAction()
{
    return d->forwardAction;
}


void UrlHistory::setUrl( const QUrl& url )
{
    d->m_currentUrl = url;
    if ( !d->m_currentUrl.isEmpty() ) {
        d->m_backwardHistory << d->m_currentUrl;
    }
    d->m_forwardHistory.clear();
    d->updateActions();
}


void UrlHistory::backward()
{
    if ( !d->m_backwardHistory.isEmpty() ) {
        QUrl url = d->m_backwardHistory.pop();
        d->m_forwardHistory.push( d->m_currentUrl );
        d->m_currentUrl = url;
        emit urlChanged( url );
        d->updateActions();
    }
}


void UrlHistory::forward()
{
    if ( !d->m_forwardHistory.isEmpty() ) {
        QUrl url = d->m_forwardHistory.pop();
        d->m_backwardHistory.push( d->m_currentUrl );
        d->m_currentUrl = url;
        emit urlChanged( url );
        d->updateActions();
    }
}

#include "urlhistory.moc"
