/* This file is part of the Nepomuk Project
   Copyright (c) 2009 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "buggerpopup.h"
#include "buggertray.h"
#include "lino.h"
#include "utils.h"

#include <QtGui/QGroupBox>
#include <QtGui/QVBoxLayout>
#include <QtGui/QToolButton>

#include <Nepomuk/Types/Class>

#include <KUrlLabel>
#include <KRun>
#include <KLocale>
#include <KIcon>


BuggerPopup::BuggerPopup( QWidget* parent )
    : KPassivePopup( parent )
{
    setAutoDelete( true );
    QWidget* w = new QWidget( this );
    QGridLayout* wl = new QGridLayout( w );
    wl->setMargin( 0 );
    wl->setSpacing( 2 );

    m_title = new QLabel( w );
    QFont fnt( m_title->font() );
    fnt.setBold( true );
    fnt.setItalic( true );
    m_title->setFont( fnt );

    m_boxLayout = new QVBoxLayout;
    m_boxLayout->setMargin( 0 );
    m_boxLayout->setSpacing( 2 );

    QToolButton* closeButton = new QToolButton( w );
    closeButton->setIcon( KIcon( "dialog-close" ) );
    closeButton->setAutoRaise( true );
    closeButton->setToolTip( i18n( "Close this popup" ) );
    connect( closeButton, SIGNAL( clicked() ), this, SLOT( close() ) );

    wl->addWidget( m_title, 0, 0, 1, 2 );
    wl->addItem( m_boxLayout, 1, 0, 1, 2 );
    wl->addWidget( closeButton, 2, 1, 1, 1 );
    wl->setColumnStretch( 0, 1 );

    setView( w );
}


BuggerPopup::~BuggerPopup()
{
}


void BuggerPopup::setDevice( const Solid::Device& dev )
{
    m_title->setText( i18n( "Found Links related to device %1 - %2", dev.vendor(), dev.product() ) );
}


void BuggerPopup::setLinks( const WebPage::List& bugs, const WebPage::List& threads, const WebPage::List& others )
{
    foreach( const WebPage& page, threads ) {
        QGroupBox* box = groupBoxForType( Lino::Vocabulary::LINO::ForumThread() );
        box->setTitle( i18n( "Forum Threads" ) );
        createLink( page.title(), page.url(), box );
    }
    foreach( const WebPage& page, bugs ) {
        QGroupBox* box = groupBoxForType( Lino::Vocabulary::LINO::Bug() );
        box->setTitle( i18n( "Bugs" ) );
        createLink( page.title(), page.url(), box );
    }
    foreach( const WebPage& page, others ) {
        QGroupBox* box = groupBoxForType( page.type() );
        createLink( page.title(), page.url(), box );
    }
}


QGroupBox* BuggerPopup::groupBoxForType( Nepomuk::Types::Class type )
{
    if ( !m_boxes.contains( type.uri() ) ) {
        QGroupBox* box = new QGroupBox( view() );
        box->setFlat( true );
        box->setTitle( Lino::capitalize( type.label() ) );
        QVBoxLayout* layout = new QVBoxLayout( box );
        layout->setMargin( 0 );
        m_boxes.insert( type.uri(), box );
        m_boxLayout->addWidget( box );
    }
    return m_boxes[type.uri()];
}


void BuggerPopup::createLink( const QString& title, const KUrl& url, QWidget* parent )
{
    KUrlLabel* label = new KUrlLabel( parent );
    label->setText( title );
    label->setUrl( url.url() );
    parent->layout()->addWidget( label );
    connect( label, SIGNAL( leftClickedUrl(QString) ),
             SLOT(openLink(QString)));
}


void BuggerPopup::openLink( const QString& url )
{
    ( void )new KRun( KUrl( url ), this );
    hide();
}


void BuggerPopup::showBugsForDevice( const Solid::Device& dev,
                                     const WebPage::List& bugs,
                                     const WebPage::List& threads,
                                     const WebPage::List& others,
                                     BuggerTray* parent )
{
    BuggerPopup* popup = new BuggerPopup();
    popup->setDevice( dev );
    popup->setLinks( bugs, threads, others );
    popup->setTimeout( 0 );
    QPoint pos = popup->calculateNearbyPoint( parent->geometry() );
    popup->show(pos);
    popup->moveNear(parent->geometry());
}

#include "buggerpopup.moc"
