/* This file is part of the Nepomuk Project
   Copyright (c) 2008 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "bug.h"
#include "bom.h"
#include "swimconnection.h"

#include <QtCore/QSharedData>


class Lino::Bug::Private : public QSharedData
{
public:
    QString title;
    Nepomuk::Resource resource;
    QUrl state;
    KUrl bugReport;
    mutable Nepomuk::Thing thing;
};


Lino::Bug::Bug()
    : d( new Private() )
{
}


Lino::Bug::Bug( const Bug& other )
{
    d = other.d;
}


Lino::Bug::~Bug()
{
}


Lino::Bug& Lino::Bug::operator=( const Bug& other )
{
    d = other.d;
    return *this;
}


bool Lino::Bug::isValid() const
{
    return d->bugReport.isValid();
}


QString Lino::Bug::title() const
{
    return d->title;
}


Nepomuk::Resource Lino::Bug::remoteResource() const
{
    return Nepomuk::Resource( resourceUri(), Vocabulary::BOM::Issue(), SwimConnection::instance()->resourceManager() );
}


Nepomuk::Resource Lino::Bug::localResource() const
{
    return d->resource;
}


QUrl Lino::Bug::resourceUri() const
{
    return d->resource.resourceUri();
}


QUrl Lino::Bug::state() const
{
    return d->state;
}


KUrl Lino::Bug::bugReportUrl() const
{
    return d->bugReport;
}


void Lino::Bug::setTitle( const QString& title )
{
    d->title = title;
}


void Lino::Bug::setResourceUri( const QUrl& uri )
{
    d->resource = uri;
}


void Lino::Bug::setState( const QUrl& state )
{
    d->state = state;
}


void Lino::Bug::setBugReportUrl( const KUrl& url )
{
    d->bugReport = url;
}
