/* This file is part of the Nepomuk Project
   Copyright (c) 2009 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "swimconnection.h"
#include "settings.h"

#include <KGlobal>

#include <QtCore/QCoreApplication>

#include <Soprano/Vocabulary/NAO>
#include <Soprano/Statement>
#include <Soprano/Node>


K_GLOBAL_STATIC(SwimConnection, s_swimInstance)

SwimConnection::SwimConnection( QObject* parent )
    : SparqlModel(),
      m_resourceManager( 0 )
{
    qAddPostRoutine( s_swimInstance.destroy );
    setParent( parent );
    updateConnectionSettings();
}


SwimConnection::~SwimConnection()
{
    qRemovePostRoutine( s_swimInstance.destroy );
    m_resourceManager->deleteInstance();
}


Nepomuk::ResourceManager* SwimConnection::resourceManager()
{
    if( !m_resourceManager )
        m_resourceManager = Nepomuk::ResourceManager::createManagerForModel( this );
    return m_resourceManager;
}


void SwimConnection::updateConnectionSettings()
{
    QUrl dbUrl = Settings::database();
    kDebug() << "Connecting to" << dbUrl.host() << Settings::port() << Settings::username();
    setHost( dbUrl.host(), Settings::port() );
    setUser( Settings::username(), Settings::password() );
    setPath( dbUrl.path() );
}


Soprano::Error::ErrorCode SwimConnection::addStatement( const Soprano::Statement& s )
{
    kDebug() << s;
    //
    // Make sure all contexts we create are marked as such.
    // This is the most awful slow solution there is but for now it will do
    //
    Soprano::Node c = s.context();
    if ( c.isValid() ) {
        if ( !containsAnyStatement( c, Soprano::Vocabulary::NAO::creator(), Soprano::Node() ) ) {
            QUrl user = userResourceUri();
            SparqlModel::addStatement( Soprano::Statement( c, Soprano::Vocabulary::NAO::creator(), user, user ) );
        }
    }

    return SparqlModel::addStatement( s );
}


QUrl SwimConnection::userResourceUri() const
{
    return QUrl( QLatin1String( "http://doc4.mandriva.org/users/" ) + Settings::username() );
}


SwimConnection* SwimConnection::instance()
{
    return s_swimInstance;
}

#include "swimconnection.moc"
