/* This file is part of the Nepomuk Project
   Copyright (c) 2008-2009 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "utils.h"
#include "lino.h"

#include <QtCore/QString>

#include <KLocale>

#include <nepomuk/pimo.h>

QUrl Lino::determineResourceTypeFromUrl( const KUrl& url )
{
    // HACK: use hardcoded namespaces to determine if it is a bug or a forum entry
    QString mandrivaForumNamespace( "http://forum.mandriva.com/viewtopic.php" );
    QString ubuntuForumNamespace( "http://ubuntuforums.org/showthread.php" );
    QString kdeBugNamespace( "http://bugs.kde.org/show_bug.cgi" );
    QString mandrivaBugNamespace( "https://qa.mandriva.com/show_bug.cgi" );
    QString hardwareNamespace( "http://hardware4linux.info/component/" );

    if ( url.url().startsWith( kdeBugNamespace ) ||
         url.url().startsWith( mandrivaBugNamespace ) )
        return Lino::Vocabulary::LINO::Bug();
    else if ( url.url().startsWith( mandrivaForumNamespace ) ||
              url.url().startsWith( ubuntuForumNamespace ) )
        return Lino::Vocabulary::LINO::ForumThread();
    else if ( url.url().startsWith( hardwareNamespace ) )
        return Lino::Vocabulary::LINO::Hardware();
    else
        return Nepomuk::Vocabulary::PIMO::Thing();
}


QString Lino::bugStateString( const QUrl& state )
{
    if ( state == Lino::Vocabulary::LINO::Unconfirmed() )
        return i18nc( "@label:listbox Filter for bugs", "Unconfirmed" );

    else if ( state == Lino::Vocabulary::LINO::New() )
        return i18nc( "@label:listbox Filter for bugs", "New" );

    else if ( state == Lino::Vocabulary::LINO::Assigned() )
        return i18nc( "@label:listbox Filter for bugs", "Assigned" );

    else if ( state == Lino::Vocabulary::LINO::Reopened() )
        return i18nc( "@label:listbox Filter for bugs", "Reopened" );

    else if ( state == Lino::Vocabulary::LINO::Resolved() )
        return i18nc( "@label:listbox Filter for bugs", "Resolved" );

    else if ( state ==Lino::Vocabulary::LINO::Closed() )
        return i18nc( "@label:listbox Filter for bugs", "Verified" );

    else
        return QString();
}


QString Lino::cleanupPageTitle( const QString& title )
{
    // the mandriva forum uses a |
    int pos = title.indexOf( '|' );
    if ( pos > 0 ) {
        return title.left( pos ).simplified();
    }

    if ( title.startsWith( "Hardware for Linux - " ) ) {
        return title.mid( 21 ).simplified();
    }

    return title;
}


// very stupid string distance taken from playground/base/nepomuk-kde/annotationplugins/plugins/pimoplugintools.cpp
qreal Lino::calculateDistance( const QString& s1, const QString& s2 )
{
    // FIXME: use some smarter distance
    if ( s1.compare( s2, Qt::CaseInsensitive ) == 0 ) {
        return 0.0;
    }
    else {
        int diff = qAbs( s1.length() - s2.length() );
        int len = qMax( s1.length(), s2.length() );
        qreal d = ( qreal )diff/( qreal )len;

        int pos = s1.indexOf( s2, 0, Qt::CaseInsensitive );
        if ( pos == 0 ) {
            // better match
            d *= 0.7;
        }
        return d;
    }
}


QString Lino::capitalize( const QString& s )
{
    if ( s.length() ) {
        QString sc( s[0].toUpper() );
        if ( s.length() > 1 )
            sc += s.mid( 1 );
        return sc;
    }
    else {
        return QString();
    }
}


QString Lino::buildVirtuosoFullTextQuery( const QString& s, QueryType type )
{
    // split words and remove punctuation
    QStringList words = s.split( QRegExp("[\\s\\(\\)\\.\\,\\;\\:]"), QString::SkipEmptyParts );

    // remove numbers
    QStringList::iterator it = words.begin();
    while ( it != words.end() ) {
        bool isNumber = false;
        it->toInt( &isNumber );
        if ( isNumber )
            it = words.erase( it );
        else
            ++it;
    }

    // merge words
    return words.join( type == AndQuery ? QLatin1String( " AND " ) : QLatin1String( " OR " ) );
}
