/* This file is part of the Nepomuk Project
   Copyright (c) 2009 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "webpage.h"

#include <QtCore/QMimeData>
#include <QtCore/QDataStream>
#include <QtCore/QByteArray>
#include <QtCore/QIODevice>


static const char* s_webPageListMime = "application/x-kde4-webpagelist";

bool WebPage::List::canDecode( const QMimeData* mimeData )
{
    return mimeData->hasFormat( s_webPageListMime ) || KUrl::List::canDecode( mimeData );
}


void WebPage::List::populateMimeData( QMimeData* mimeData )
{
    QByteArray data;
    QDataStream s( &data, QIODevice::WriteOnly );
    foreach( const WebPage& page, *this ) {
        s << page.url() << page.title();
    }
    mimeData->setData( s_webPageListMime, data );
}


WebPage::List WebPage::List::fromMimeData( const QMimeData* mimeData )
{
    List pages;
    if ( canDecode( mimeData ) ) {
        QByteArray payload = mimeData->data(s_webPageListMime);
        QDataStream s( payload );
        while ( !s.atEnd() ) {
            KUrl url;
            QString title;
            s >> url >> title;
            pages << WebPage( url, title );
        }
    }
    else if ( KUrl::List::canDecode( mimeData ) ) {
        pages = KUrl::List::fromMimeData( mimeData );
    }
    return pages;
}


QStringList WebPage::List::mimeDataTypes()
{
    return QStringList() << s_webPageListMime;
}
