/* This file is part of the Nepomuk Project
   Copyright (c) 2009 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef _WEB_PAGE_H_
#define _WEB_PAGE_H_

#include <KUrl>
#include <QtCore/QStringList>
#include <Nepomuk/Types/Class>

class QMimeData;

class WebPage {
public:
    WebPage() {}

    WebPage( const KUrl _url, const QString& _title, const Nepomuk::Types::Class& type = Nepomuk::Types::Class() )
        : m_url(_url),
          m_title(_title),
          m_type(type) {}

    WebPage( const KUrl& _url )
        : m_url(_url),
          m_title(_url.url()) {}

    operator KUrl() const { return m_url; }
    KUrl url() const { return m_url; }
    QString title() const { return m_title; }
    Nepomuk::Types::Class type() const { return m_type; }

    bool operator==( const WebPage& other ) const { return m_url == other.m_url; }
    bool operator!=( const WebPage& other ) const { return m_url != other.m_url; }

    class List : public QList<WebPage>
    {
    public:
        List() {}

        List( const WebPage& page ) {
            append( page );
        }

        List( const KUrl::List& urls ) {
            foreach( const KUrl& url, urls ){
                append( url );
            }
        }

        void populateMimeData( QMimeData* mimeData );

        static bool canDecode( const QMimeData* );
        static List fromMimeData( const QMimeData* );
        static QStringList mimeDataTypes();
    };

private:
    KUrl m_url;
    QString m_title;
    Nepomuk::Types::Class m_type;
};

Q_DECLARE_METATYPE(WebPage)

#endif
