/* This file is part of the Nepomuk Project
   Copyright (c) 2009 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef _CLIPBOARD_MODEL_H_
#define _CLIPBOARD_MODEL_H_

#include <QtCore/QAbstractListModel>
#include "webpage.h"

#include <KUrl>

class ClipboardModel : public QAbstractListModel
{
    Q_OBJECT

public:
    ClipboardModel( QObject* parent = 0 );
    ~ClipboardModel();

    enum Roles {
        UrlRole = 7777,
        WebPageRole = 7778
    };

    int rowCount( const QModelIndex& parent = QModelIndex() ) const;
    QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const;
    QMimeData* mimeData( const QModelIndexList& indexes ) const;
    QStringList mimeTypes( ) const;
    Qt::ItemFlags flags( const QModelIndex& index ) const;

public Q_SLOTS:
    void addUrl( const KUrl& url, const QString& title );
    void addPage( const WebPage& page );
    void clear();

private:
    QList<WebPage> m_entries;
};

#endif
