/* This file is part of the Nepomuk Project
   Copyright (c) 2009 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#include "forumpost.h"
#include "forumthread.h"

#include <QtCore/QSharedData>

#include <KUrl>

#include <dom/html_document.h>
#include <dom/dom_string.h>


class ForumPost::Private : public QSharedData
{
public:
    ForumThread thread;
    QUrl resourceUri;
    KUrl webLink;
    QString title;
};


ForumPost::ForumPost()
    : d( new Private() )
{
}


ForumPost::ForumPost( const ForumPost& other )
{
    d = other.d;
}


ForumPost::~ForumPost()
{
}


ForumPost& ForumPost::operator=( const ForumPost& other )
{
    d = other.d;
    return *this;
}


bool ForumPost::isValid() const
{
    return !d->resourceUri.isEmpty();
}


ForumThread ForumPost::thread() const
{
    return d->thread;
}


QUrl ForumPost::resourceUri() const
{
    return d->resourceUri;
}


KUrl ForumPost::webLink() const
{
    return d->webLink;
}


QString ForumPost::title() const
{
    return d->title;
}


ForumPost ForumPost::parsePost( const KUrl& url, const DOM::HTMLDocument& doc )
{
    // TODO: do some actual parsing
    ForumPost post;
    post.d->webLink = url;
    post.d->resourceUri = url;
    post.d->title = doc.title().string();
    return post;
}
