/* This file is part of the Nepomuk Project
   Copyright (c) 2009 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef _SIDEBAR_WIDGET_H_
#define _SIDEBAR_WIDGET_H_

#include <QtGui/QWidget>
#include "ui_sidebarwidget.h"
#include "ui_prefs_base.h"

#include <nepomuk/resource.h>

class QStandardItemModel;
class ClipboardModel;
class AnnotationRecommendationModel;
class QModelIndex;
class KJob;
class KProgressDialog;
namespace DOM {
    class HTMLDocument;
}

class SidebarWidget : public QWidget, public Ui::SidebarWidget
{
    Q_OBJECT

public:
    SidebarWidget( QWidget* parent );
    ~SidebarWidget();

    void setUrl( const KUrl& url );
    KUrl currentUrl() const;

    bool eventFilter( QObject* obj, QEvent* event );

Q_SIGNALS:
    void requestURL( const KUrl& );

private Q_SLOTS:
    void slotAddUrl();
    void slotResourceChanged();
    void slotUploadAnnotations();
    void slotClipboardDoubleClicked( const QModelIndex& index );
    void slotAnnotationsUploaded( KJob* job );
    void slotPreferences();

private:
    DOM::HTMLDocument findCurrentDocument();
    bool checkSettings();

    KUrl m_url;
    Nepomuk::Resource m_resource;
    QStandardItemModel* m_historyModel;
    ClipboardModel* m_clipboard;
    AnnotationRecommendationModel* m_recommendationModel;

    KProgressDialog* m_uploadProgressDialog;

    Ui::prefs_base ui_prefs_base ;
};

#endif
